@@ -2,6 +2,7 @@ package cli
 
 import (
 	"fmt"
+	"os"
 	"path/filepath"
 	"strings"
 
@@ -70,6 +71,11 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 }
 
 func runInit(sh, command string) {
+	if os.Getenv("CURSOR_AGENT") == "1" {
+		log.Errorf("oh-my-posh init is disabled when running inside Cursor agent mode")
+		return
+	}
+
 	if debug {
 		log.Enable(plain)
 	}
@@ -80,7 +86,7 @@ func runInit(sh, command string) {
 
 	initCache(sh)
 
-	cfg := config.Load(configFlag, false)
+	cfg := config.Load(configFlag)
 
 	flags := &runtime.Flags{
 		Shell:      sh,
@@ -112,8 +118,10 @@ func runInit(sh, command string) {
 	var output string
 
 	switch {
-	case printOutput, debug:
-		output = shell.PrintInit(env, feats, &startTime)
+	case debug:
+		output = shell.Debug(env, feats, &startTime)
+	case printOutput:
+		output = shell.Script(env, feats)
 	default:
 		output = shell.Init(env, feats)
 	}
@@ -167,10 +175,15 @@ func getFullCommand(cmd *cobra.Command, args []string) string {
 }
 
 func initCache(sh string) {
-	if !printOutput && (sh == shell.PWSH || sh == shell.ELVISH) {
-		cache.Init(sh)
-		return
-	}
+	switch {
+	case !printOutput:
+		if (eval && sh == shell.PWSH) || sh == shell.ELVISH {
+			cache.Init(sh)
+			return
+		}
 
-	cache.Init(sh, cache.NewSession, cache.Persist)
+		fallthrough
+	default:
+		cache.Init(sh, cache.NewSession, cache.Persist)
+	}
 }
